@@ -1,9 +1,9 @@
 package App::idxdb;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-22'; # DATE
+our $DATE = '2021-06-16'; # DATE
 our $DIST = 'App-idxdb'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,8 +11,9 @@ use warnings;
 use Log::ger;
 
 #use Data::Clone qw(clone);
-use DateTime;
+use DateTime; # TODO: defer this, too heavy for tab completion
 use File::chdir;
+#use List::Util qw(min max);
 
 sub _set_args_default {
     my $args = shift;
@@ -162,11 +163,13 @@ our %argsopt_filter_date = (
             '1week'  => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>     7); $_[0]{date_end} = $today}},
             'month'  => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>    30); $_[0]{date_end} = $today}},
             '1month' => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>    30); $_[0]{date_end} = $today}},
+            '2month' => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>    60); $_[0]{date_end} = $today}},
             '3month' => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>    90); $_[0]{date_end} = $today}},
             '6month' => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>   180); $_[0]{date_end} = $today}},
             'ytd'    => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->set(month=>1, day=>1);  $_[0]{date_end} = $today}},
             'year'   => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>   365); $_[0]{date_end} = $today}},
             '1year'  => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>   365); $_[0]{date_end} = $today}},
+            '2year'  => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=> 2*365); $_[0]{date_end} = $today}},
             '3year'  => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=> 3*365); $_[0]{date_end} = $today}},
             '5year'  => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=> 5*365); $_[0]{date_end} = $today}},
             '10year' => {is_flag=>1, code=>sub {$_[0]{date_start} = $today->clone->subtract(days=>10*365); $_[0]{date_end} = $today}},
@@ -650,10 +653,17 @@ sub daily {
             output   => $tempfilename,
             title    => join(",", @$fields)." of ".join(",",@$stocks)." from $mindate to $maxdate",
             xlabel   => 'date',
-            ylabel   => "\%",
+            ylabel   => $fields->[0],
+            (@$fields > 1 ? (y2label  =>
+                                 $fields->[1] .
+                                 (@$fields > 2 ? ", $fields->[2]" : "") .
+                                 (@$fields > 3 ? ", ...":"")) : ()),
             timeaxis => 'x',
             xtics    => {labelfmt=>'%Y-%m-%d', rotate=>"30 right"},
-            #yrange   => [0, 100],
+            #yrange   => [0, 5000],
+            #y2range  => [-0, 1000_000_000],
+            ytics    => {mirror=>'off'}, # no effect?
+            y2tics   => {mirror=>'off'}, # no effect?
         );
         my $i = -1;
         my @datasets;
@@ -669,6 +679,7 @@ sub daily {
                     title   => "$stock.$field",
                     color   => $colors[$i],
                     style   => 'lines',
+                    ($i ? (axes => "x1y2") : ()),
                 );
             }
         }
@@ -740,7 +751,7 @@ App::idxdb - Import data for stocks on the IDX (Indonesian Stock Exchange) and p
 
 =head1 VERSION
 
-This document describes version 0.004 of App::idxdb (from Perl distribution App-idxdb), released on 2021-01-22.
+This document describes version 0.005 of App::idxdb (from Perl distribution App-idxdb), released on 2021-06-16.
 
 =head1 SYNOPSIS
 
@@ -748,6 +759,12 @@ See the included CLI script L<idxdb>.
 
 =head1 DESCRIPTION
 
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on netbook-dell-xps13)
+
+perlancar (on netbook-dell-xps13) <perlancar@gmail.com>
+
 =head1 FUNCTIONS
 
 
@@ -755,7 +772,7 @@ See the included CLI script L<idxdb>.
 
 Usage:
 
- daily(%args) -> [status, msg, payload, meta]
+ daily(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Show data from daily stockE<sol>trading summary.
 
@@ -765,9 +782,9 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<date_end> => I<date> (default: 1611273600)
+=item * B<date_end> => I<date> (default: 1623801600)
 
-=item * B<date_start> => I<date> (default: 1608681600)
+=item * B<date_start> => I<date> (default: 1621209600)
 
 =item * B<fields> => I<array[str]> (default: ["Volume","Value","ForeignNetBuy"])
 
@@ -784,12 +801,12 @@ Show graph instead of table.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -799,7 +816,7 @@ Return value:  (any)
 
 Usage:
 
- ownership(%args) -> [status, msg, payload, meta]
+ ownership(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Show ownership of some stock through time.
 
@@ -819,9 +836,9 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<date_end> => I<date> (default: 1611273600)
+=item * B<date_end> => I<date> (default: 1623801600)
 
-=item * B<date_start> => I<date> (default: 1608681600)
+=item * B<date_start> => I<date> (default: 1621209600)
 
 =item * B<fields> => I<array[str]> (default: ["LocalTotal","ForeignTotal"])
 
@@ -840,12 +857,12 @@ Show legend of ownership instead (e.g. ForeignIB = foreign bank, etc).
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -855,7 +872,7 @@ Return value:  (any)
 
 Usage:
 
- update(%args) -> [status, msg, payload, meta]
+ update(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Update data.
 
@@ -882,12 +899,12 @@ If not specified, will default to C<~/idxdb.db>.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -901,7 +918,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-idxdb>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-idxdb/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-idxdb>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
